/*
 kstrax
 Copyright (c) 2005,2007 Hitachi,Ltd.,
 Created by Satoru Moriya <satoru.moriya.br@hitachi.com>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _KSTRAX_H_
#define _KSTRAX_H_

#define KSTRAX_VERSION    "1.0.2"
#define KSTRAX_FNAME_MAX  1024 

extern int kstrax_cflag, kstrax_kflag, kstrax_rflag;
extern int kstrax_Rflag, kstrax_gflag;

void kstrax_set_nr_syscalls(int);
int kstrax_get_nr_syscalls(void);

#endif  /* _KSTRAX_H_ */
